operation

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	//go:embed asset/favicon.ico
	Favicon []byte
)

Functions

func Admin

func Admin() http.Handler

Admin returns an http.Handler that serves the UI files. It handles SPA routing (serving index.html for unknown paths if needed, though Agbero is mostly a dashboard, so static file serving is usually enough).

Types

This section is empty.

Directories

Path Synopsis

Jump to